/****************************************************************************
 * This file is part of the project AqDatabase.
 * AqDatabase (c) by 2016 Martin Preuss, all rights reserved.
 *
 * The license for this file can be found in the file COPYING which you
 * should have received along with this file.
 ****************************************************************************/

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif


#include "createdb.h"
#include "type1.h"
#include "type2.h"

#include <aqdatabase/aqdb.h>
#include <aqdatabase/aqdb_db.h>

#include <gwenhywfar/debug.h>




int create_database(const char *url, const char *dirname, const char *fname) {
  AQDB_DB *db=NULL;
  AQDB_COLUMN_LIST *cl;
  int rv;

  rv=AQDB_DbFactory(url, &db);
  if (rv<0) {
    DBG_ERROR(0, "ERROR: Unable to instantiate db (%d)", rv);
    return rv;
  }

  rv=AQDB_DB_Create(db, AQDB_ACTION_FLAGS_READ | AQDB_ACTION_FLAGS_WRITE);
  if (rv<0) {
    DBG_ERROR(0, "ERROR: Unable to create db (%d)", rv);
    AQDB_DB_free(db);
    return rv;
  }

#if 0
  rv=AQDB_DB_Close(db, 0);
  if (rv<0) {
    DBG_ERROR(0, "ERROR: Unable to close db (%d)", rv);
    AQDB_DB_free(db);
    return rv;
  }
#endif

  rv=AQDB_DB_Open(db, AQDB_ACTION_FLAGS_READ | AQDB_ACTION_FLAGS_WRITE);
  if (rv<0) {
    DBG_ERROR(0, "ERROR: Unable to open db (%d)", rv);
    AQDB_DB_free(db);
    return rv;
  }

  rv=AQDB_DB_BeginEdit(db, 0);
  if (rv<0) {
    DBG_ERROR(0, "ERROR: Unable to begin edit session (%d)", rv);
    AQDB_DB_free(db);
    return rv;
  }

  /* create type 1 */
  cl=Type1_CreateColumnList();
  rv=AQDB_DB_CreateTable(db, "type1", AQDB_ACTION_FLAGS_READ | AQDB_ACTION_FLAGS_WRITE, cl);
  if (rv<0) {
    DBG_ERROR(0, "ERROR: Unable to create table (%d)", rv);
    AQDB_Column_List_free(cl);
    AQDB_DB_free(db);
    return rv;
  }
  AQDB_Column_List_free(cl);


  /* create type 2 */
  cl=Type2_CreateColumnList();
  rv=AQDB_DB_CreateTable(db, "type2", AQDB_ACTION_FLAGS_READ | AQDB_ACTION_FLAGS_WRITE, cl);
  if (rv<0) {
    DBG_ERROR(0, "ERROR: Unable to create table (%d)", rv);
    AQDB_Column_List_free(cl);
    AQDB_DB_free(db);
    return rv;
  }
  AQDB_Column_List_free(cl);


  rv=AQDB_DB_EndEdit(db, 0);
  if (rv<0) {
    DBG_ERROR(0, "ERROR: Unable to end edit session (%d)", rv);
    AQDB_DB_free(db);
    return rv;
  }

  rv=AQDB_DB_Close(db, 0);
  if (rv<0) {
    DBG_ERROR(0, "ERROR: Unable to close db (%d)", rv);
    AQDB_DB_free(db);
    return rv;
  }

  fprintf(stderr, "Ok.\n");
  AQDB_DB_free(db);
  return 0;
}





