/****************************************************************************
 * This file is part of the project AqDatabase.
 * AqDatabase (c) by 2016 Martin Preuss, all rights reserved.
 *
 * The license for this file can be found in the file COPYING which you
 * should have received along with this file.
 ****************************************************************************/

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif


#include "createobjects.h"
#include "type1.h"
#include "type2.h"

#include <gwenhywfar/debug.h>



int create_type1_objects(AQDB_DB *db, AQDB_ID tableId, int numberOfObjects, AQDB_ID startId) {
  int rv;
  int n;

  for (n=0; n<numberOfObjects; n++) {
    TYPE1 *t;
    GWEN_DATE *dt;
    GWEN_TIME *ti;
    AQDB_OBJECT *o=NULL;
    char numbuf[256];
    AQDB_ID oid;

    oid=startId+n;

    t=Type1_new();

    Type1_SetId(t, oid);

    snprintf(numbuf, sizeof(numbuf)-1, "%d-stringField1", oid);
    numbuf[sizeof(numbuf)-1]=0;
    Type1_SetStringField1(t, numbuf);

    /* date is 2000 / 01 / (objectId mod 30) */
    dt=GWEN_Date_fromGregorian(2000, 1, (oid % 20)+1);
    Type1_SetDateField1(t, dt);
    GWEN_Date_free(dt);

    snprintf(numbuf, sizeof(numbuf)-1, "%d-stringField2", oid);
    numbuf[sizeof(numbuf)-1]=0;
    Type1_SetStringField2(t, numbuf);

    Type1_SetUint32Field1(t, oid);

    ti=GWEN_Time_new(1980, 1, (oid % 10)+1, 12, 0, 0, 1);
    Type1_SetTimestampField1(t, ti);
    GWEN_Time_free(ti);

    /* date is 2000 / 01 / (objectId mod 30) */
    dt=GWEN_Date_fromGregorian(2000, 1, (oid % 20)+1);
    Type1_SetDateField2(t, dt);
    GWEN_Date_free(dt);

    Type1_SetUint32Field2(t, oid);

    /* store object */
    rv=Type1_CreateObject(db, tableId, 0, &o);
    if (rv<0) {
      fprintf(stderr, "ERROR: Unable to create object (%d)\n", rv);
      return rv;
    }
    rv=Type1_toObject(t, o);
    if (rv<0) {
      DBG_ERROR(0, "ERROR: Unable to transform type to object (%d)", rv);
      AQDB_Object_free(o);
      return rv;
    }

    rv=AQDB_DB_AddObject(db, tableId, o);
    if (rv<0) {
      DBG_ERROR(0, "ERROR: Unable to add object (%d)", rv);
      AQDB_Object_free(o);
      return rv;
    }
    AQDB_Object_free(o);
  }

  return 0;
}




int create_type2_objects(AQDB_DB *db, AQDB_ID tableId, int numberOfObjects, AQDB_ID startId) {
  int rv;
  int n;

  for (n=0; n<numberOfObjects; n++) {
    TYPE2 *t;
    GWEN_DATE *dt;
    GWEN_TIME *ti;
    AQDB_OBJECT *o=NULL;
    char numbuf[256];
    AQDB_ID oid;

    oid=startId+n;

    t=Type2_new();

    Type2_SetId(t, oid);

    snprintf(numbuf, sizeof(numbuf)-1, "%d-stringField1", oid);
    numbuf[sizeof(numbuf)-1]=0;
    Type2_SetStringField1(t, numbuf);

    /* date is 2000 / 01 / (objectId mod 30) */
    dt=GWEN_Date_fromGregorian(2000, 1, (oid % 20)+1);
    Type2_SetDateField1(t, dt);
    GWEN_Date_free(dt);

    snprintf(numbuf, sizeof(numbuf)-1, "%d-stringField2", oid);
    numbuf[sizeof(numbuf)-1]=0;
    Type2_SetStringField2(t, numbuf);

    Type2_SetUint32Field1(t, oid);

    ti=GWEN_Time_new(1980, 1, (oid % 10)+1, 12, 0, 0, 1);
    Type2_SetTimestampField1(t, ti);
    GWEN_Time_free(ti);

    /* date is 2000 / 01 / (objectId mod 30) */
    dt=GWEN_Date_fromGregorian(2000, 1, (oid % 20)+1);
    Type2_SetDateField2(t, dt);
    GWEN_Date_free(dt);

    Type2_SetUint32Field2(t, oid);

    /* store object */
    rv=Type2_CreateObject(db, tableId, 0, &o);
    if (rv<0) {
      DBG_ERROR(0, "ERROR: Unable to create object (%d)", rv);
      return rv;
    }
    rv=Type2_toObject(t, o);
    if (rv<0) {
      DBG_ERROR(0, "ERROR: Unable to transform type to object (%d)", rv);
      AQDB_Object_free(o);
      return rv;
    }

    rv=AQDB_DB_AddObject(db, tableId, o);
    if (rv<0) {
      DBG_ERROR(0, "ERROR: Unable to add object (%d)", rv);
      AQDB_Object_free(o);
      return rv;
    }
    AQDB_Object_free(o);
  }

  return 0;
}







